# Class: name
#
#
class baruwa {
	include uwsgi
	include nginx
	include exim
	include cron
	include sudo
	if $baruwa_pgsql_host == '127.0.0.1' {
	    require baruwa::db
	    include sphinx
	    include pgbouncer
	    include postgresql::server
	}

    $app_uuid = uuid($baruwa_web_vhost)
    $session_secret = random_password(25)
    $baruwa_path = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "/usr/lib/python2.7/dist-packages/baruwa",
        default => "/usr/lib/python2.6/site-packages/baruwa",
    }
    
    $cracklib_package = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "cracklib-runtime",
        default => "cracklib",
    }
    
    if $operatingsystem in ['Ubuntu', 'Debian'] {
        package { "python-repoze.who":
            ensure => installed,
        }
        package { "$cracklib_package":
            ensure => installed,
        }
        package { "baruwa":
            ensure => installed,
            require => Package["python-repoze.who"],
        }
    }else{
        package { "$cracklib_package":
            ensure => installed,
        }
        package { "baruwa":
            ensure => installed,
        }
    }

    # package { "python-amqplib":
    #     ensure => installed,
    # }

    service { "baruwa":
        enable     => true,
        ensure     => running,
        hasrestart => true,
        hasstatus  => true,
        require => [Package["baruwa"], Service["crond"]],
    }

    user { "baruwa":
        groups => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => ["baruwa", "Debian-exim"],
            default => ["baruwa", "exim"],
        },
        require => [Package["exim"], Package["baruwa"]],
    }

    file { "/etc/baruwa/production.ini":
        content => template("baruwa/production.ini.erb"),
        require => Package["baruwa"],
        notify => Service["baruwa"],
    }

    file { "/etc/nginx/conf.d/default.conf":
        content => template("baruwa/nginx.conf.erb"),
        require => [Package["baruwa"], Package["nginx"]],
        notify => Service["nginx"],
    }

    file { "/etc/uwsgi/baruwa.ini":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/uwsgi/apps-enabled/production.ini",
            default => "/etc/uwsgi/baruwa.ini",
        },
        target => "/etc/baruwa/production.ini",
        require => [File["/etc/baruwa/production.ini"], Package["uwsgi"]],
        ensure => link,
        notify => Service["uwsgi"],
    }

    file { "/etc/sudoers.d/baruwa":
        mode    => "0440",
        owner   => "root",
        group   => "root",
        content => template("baruwa/baruwa-sudo.erb"),
        require => [Package["baruwa"], Package["sudo"]],
    }

    file { "/etc/cron.hourly/baruwa-expire-bayes":
        mode    => "0755",
        owner   => "root",
        group   => "root",
        require => Package["cronie"],
        notify  => Service["crond"],
        content => template("baruwa/baruwa-bayes.erb"),
    }

    $sqlcheck = "\"SELECT tablename FROM pg_tables WHERE tablename ='maildomains'\" | grep maildomains"
    exec { "populate-db":
        command => "paster setup-app /etc/baruwa/production.ini",
        path => "/bin:/usr/bin",
        require => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => [File["/etc/baruwa/production.ini"], Service["pgbouncer"], Service["postgresql"]],
            default => [File["/etc/baruwa/production.ini"], Package["postgresql"]],
        },
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c $sqlcheck",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c $sqlcheck",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }

    $sacheck = "\"SELECT id FROM sarules WHERE id='AWL'\" | grep AWL"
    exec { "update-sa-rules":
        command => "paster update-sa-rules /etc/baruwa/production.ini",
        path => "/usr/bin:/bin",
        require => Exec["populate-db"],
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c $sacheck",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c $sacheck",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }

    if $baruwa_pgsql_host == '127.0.0.1' {
        exec { "initial-indexing":
            command => "indexer --all --rotate",
            require => Exec["populate-db"],
            unless => $operatingsystem ? {
                /(?i:Debian|Ubuntu)/ => "ls /var/lib/sphinxsearch/messagesdelta.spa",
                default => "ls /var/lib/sphinx/messagesdelta.spa",
            },
            user => $operatingsystem ? {
                /(?i:Debian|Ubuntu)/ => "sphinxsearch",
                default => "sphinx",
            },
        }
    }

    exec { "create-admin-user":
        command => "paster create-admin-user /etc/baruwa/production.ini \
                    -u ${baruwa_admin_user} -p ${baruwa_admin_passwd} \
                    -e ${baruwa_admin_email} -t ${baruwa_timezone}",
        path => "/bin:/usr/bin",
        require => Exec["populate-db"],
        unless => $baruwa_pgsql_host ? {
            /(?i:127.0.0.1)/ => "psql -U postgres $baruwa_pgsql_db  -c 'SELECT username FROM users'|grep ${baruwa_admin_user}",
            default => "psql -h $baruwa_pgsql_host -p $baruwa_pgsql_port -U postgres $baruwa_pgsql_db  -c 'SELECT username FROM users'|grep ${baruwa_admin_user}",
        },
        environment => "PGPASSWORD=${pgsql_password}",
    }
}