# Class: exim
#
#
class exim {
    $exim_user = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "Debian-exim",
        default => "exim",
    }
    $clam_user = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "clamav",
        default => "clam",
    }
    $exim_path = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "exim4",
        default => "exim",
    }
    $clam_socket = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "/var/run/clamav/clamd.ctl",
        default => "/var/run/clamav/clamd.sock",
    }

    package { "exim":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "exim4-daemon-baruwa",
            default => "exim",
        },
        ensure => installed,
    }

    mailalias {"root":
        ensure => "present",
        recipient => "$baruwa_admin_email",
        target => "/etc/aliases",
    }

    package { ["sendmail", "postfix"]:
        ensure => absent,
        require => Package["exim"],
    }

    service { "exim":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "exim4",
            default => "exim",
        },
        enable => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => true,
            default => false,
        },
        hasrestart => true,
        hasstatus => true,
        require => Package["exim"],
    }

    file { "exim.conf":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ => "/etc/exim4/exim4.conf",
           default => "/etc/exim/exim.conf",
        },
        content => template("exim/exim.conf.erb"),
        require => Package["exim"],
    }

    file { "exim_out.conf":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ => "/etc/exim4/exim_out.conf",
           default => "/etc/exim/exim_out.conf",
        },
        content => template("exim/exim_out.conf.erb"),
        require => Package["exim"],
    }

    file { "macros.conf":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ => "/etc/exim4/macros.conf",
           default => "/etc/exim/macros.conf",
        },
        content => template("exim/macros.conf.erb"),
        require => Package["exim"],
    }

    file { "trusted-configs":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ => "/etc/exim4/trusted_configs",
           default => "/etc/exim/trusted-configs",
        },
        owner => "root",
        group => "root",
        mode => "0644",
        content => template("exim/trusted-configs.erb"),
        require => Package["exim"],
    }

    file {"exim-input-spool":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ =>  "/var/spool/exim4.in",
           default => "/var/spool/exim.in",
        },
        ensure => directory,
        owner => "$exim_user",
        group => "$exim_user",
        mode => "0750",
        require => Package["exim"],
    }

    file {"exim-input-spool-db":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ =>  "/var/spool/exim4.in/db",
           default => "/var/spool/exim.in/db",
        },
        ensure => directory,
        owner => "$exim_user",
        group => "$exim_user",
        mode => "0750",
        require => [Package["exim"], File["exim-input-spool"]],
    }

    file {"exim-input-spool-input":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ =>  "/var/spool/exim4.in/input",
           default => "/var/spool/exim.in/input",
        },
        ensure => directory,
        owner => "$exim_user",
        group => "$exim_user",
        mode => "0750",
        require => [Package["exim"], File["exim-input-spool"]],
    }

    file {"exim-input-spool-msglog":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ =>  "/var/spool/exim4.in/msglog",
           default => "/var/spool/exim.in/msglog",
        },
        ensure => directory,
        owner => "$exim_user",
        group => "$exim_user",
        mode => "0750",
        require => [Package["exim"], File["exim-input-spool"]],
    }

    file {"exim-input-spool-scan":
        path => $operatingsystem ? {
           /(?i:Debian|Ubuntu)/ =>  "/var/spool/exim4.in/scan",
           default => "/var/spool/exim.in/scan",
        },
        ensure => directory,
        owner => "$exim_user",
        group => "$exim_user",
        mode => "0750",
        require => [Package["exim"], File["exim-input-spool"]],
    }

    if $operatingsystem in ['Ubuntu', 'Debian'] {
        file { "/etc/default/exim4":
            owner => "root",
            group => "root",
            mode => "0644",
            content => template("exim/default.erb"),
            require => Package["exim"],
            notify => Service["exim"],
        }
    }
}