# Class: mailscanner
#
#
class mailscanner {
    include exim
    include cron
    include baruwa
    include clamav
    include spamassassin

    $exim_user = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "Debian-exim",
        default => "exim",
    }
    $clam_user = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "clamav",
        default => "clam",
    }
    $exim_path = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "exim4",
        default => "exim",
    }
    package { "mailscanner":
        ensure => installed,
    }

    package {"mailscanner-perl-deps":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => ["libmail-spf-perl", "libencode-detect-perl",
                        "libnet-cidr-lite-perl", "libio-string-perl", "libpod-simple-perl",
                        "libnet-dns-resolver-programmable-perl", "libparse-recdescent-perl",
                        "libmail-dkim-perl", "libinline-perl", "libnet-ip-perl", "antiword",
                        "libconvert-tnef-perl", "libdbd-pg-perl", "libdbd-mysql-perl", "unrar"],
            default => ["perl-Mail-SPF", "perl-Encode-Detect", "perl-Net-CIDR-Lite",
                        "perl-IO-String", "perl-Pod-Escapes", "perl-Pod-Simple",
                        "perl-Net-DNS-Resolver-Programmable", "perl-Parse-RecDescent",
                        "perl-Mail-DKIM", "perl-Inline", "perl-Net-IP", "antiword",
                        "perl-Convert-TNEF", "perl-DBD-Pg", "perl-DBD-MySQL", "unrar"],
        },
        ensure => installed,
    }

    service { "mailscanner":
        enable => true,
        ensure => running,
        hasrestart  => true,
        hasstatus => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => false,
            default => true,
        },
        pattern => 'MailScanner: waiting for messages',
        require => [Package["mailscanner"], Package["baruwa"], File["exim.conf"], File["exim_out.conf"], File["macros.conf"]],
    }

    file { "/etc/MailScanner/MailScanner.conf":
        content => template("mailscanner/MailScanner.conf.erb"),
        require => Package["mailscanner"],
        notify => Service["mailscanner"],
    }

    file { "/etc/MailScanner/spam.assassin.prefs.conf":
        ensure  => present,
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        notify => Service["mailscanner"],
        content => template("mailscanner/spam.assassin.prefs.conf.erb"),
    }

    file { "/etc/sysconfig/update_spamassassin":
        path => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/default/update_spamassassin",
            default => "/etc/sysconfig/update_spamassassin",
        },
        ensure  => present,
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/update_spamassassin.erb"),
    }

    file { "/etc/mail/spamassassin/local.cf":
        target => "/etc/MailScanner/spam.assassin.prefs.conf",
        require => [File["/etc/MailScanner/spam.assassin.prefs.conf"], Package["spamassassin"]],
        ensure => link,
    }

    file { ['/etc/MailScanner/reports/af',
            '/etc/MailScanner/reports/ar',
            '/etc/MailScanner/reports/bg',
            '/etc/MailScanner/reports/cs',
            '/etc/MailScanner/reports/da',
            '/etc/MailScanner/reports/el',
            '/etc/MailScanner/reports/he',
            '/etc/MailScanner/reports/hi',
            '/etc/MailScanner/reports/id',
            '/etc/MailScanner/reports/ja',
            '/etc/MailScanner/reports/lv',
            '/etc/MailScanner/reports/no',
            '/etc/MailScanner/reports/pl',
            '/etc/MailScanner/reports/ru',
            '/etc/MailScanner/reports/sv',
            '/etc/MailScanner/reports/sw',
            '/etc/MailScanner/reports/th',
            '/etc/MailScanner/reports/tr',
            '/etc/MailScanner/reports/uk',
            '/etc/MailScanner/reports/vi',
            '/etc/MailScanner/reports/xh',
            '/etc/MailScanner/reports/zh',
            '/etc/MailScanner/reports/zu']:
        target => "/etc/MailScanner/reports/en",
        require => Package["mailscanner"],
        ensure => link,
    }

    file { "/etc/cron.hourly/baruwa-clean-eximdb":
        mode    => "0755",
        owner   => "root",
        group   => "root",
        require => [Package["exim"], Package["cronie"]],
        notify  => Service["crond"],
        content => template("mailscanner/cleaneximretrydb.erb"),
    }

    file { "filename.rules":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/filename.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/filename.rules",
    }

    file { "filetype.rules":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/filetype.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/filetype.rules",
    }

    file { "filetype.rules.allowall.conf":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/filetype.rules.allowall.conf"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/filetype.rules.allowall.conf",
    }

    file { "filename.rules.allowall.conf":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/filename.rules.allowall.conf"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/filename.rules.allowall.conf",
    }

    file { "content.scanning.rules":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/content.scanning.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/content.scanning.rules",
    }

    file { "message.scanning.rules":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/scan.messages.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/scan.messages.rules",
    }

    file { "nonspam.actions.rules":
        mode => "0644",
        owner => "root",
        group => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/nonspam.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/nonspam.actions.rules",
    }

    file { "file-wrapper":
        mode => "0755",
        owner => "root",
        group => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/file-wrapper"),
        notify  => Service["mailscanner"],
        path    => "/usr/local/bin/file-wrapper",
    }

    file { "/var/spool/MailScanner":
        ensure => directory,
        owner => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "Debian-exim",
            default => "root",
        },
        group => "root",
        mode => "0775",
        require => [Package["mailscanner"], Package["baruwa"]],
    }

    file { "/var/spool/MailScanner/quarantine":
        ensure => directory,
        owner => "$exim_user",
        group => "baruwa",
        mode => "0775",
        notify  => Service["mailscanner"],
        require => [Package["mailscanner"], Package["baruwa"], File["/var/spool/MailScanner"]],
    }

    file { "/var/spool/MailScanner/archive":
        ensure => directory,
        owner => "$exim_user",
        group => "$exim_user",
        mode => "0755",
        notify  => Service["mailscanner"],
        require => [Package["mailscanner"], File["/var/spool/MailScanner"]],
    }

    file { "/var/spool/MailScanner/incoming":
        ensure => directory,
        owner => "$exim_user",
        group => "$clam_user",
        mode => "0755",
        notify  => Service["mailscanner"],
        require => [Package["mailscanner"], Package["clamav"], File["/var/spool/MailScanner"]],
    }

    if $baruwa_pgsql_host != '127.0.0.1' {
        exec { "set-remote-sphinx":
            command => "sed -e \"s/\\\"127.0.0.1\\\";/\\\"${baruwa_sphinx_host}\\\";/\" -i /usr/share/baruwa/CustomFunctions/BS.pm",
            unless => "grep -E \"\\\"${baruwa_sphinx_host}\\\";\" /usr/share/baruwa/CustomFunctions/BS.pm",
            require => Package["baruwa"],
            notify => Service["mailscanner"],
        }
    }
}