# Class: ssl
#
#
class ssl {
    # resources
    # Define: createcsr
    # Parameters:
    # $app, $host, $ou, $cn, $country, $province, $city
    #
    define createcsr ($app, $host, $ou, $cn, $country, $province, $city, $ca) {
        exec { "create-${app}-${host}-csr":
            command => "openssl req -config /etc/pki/${ca}/ssl.cnf -new \
                        -nodes -subj \"/C=${country}/ST=${province}/L=${city}/O=${ou}/CN=${cn}\" \
                        -out /etc/pki/${app}/certs/${host}.csr -key /etc/pki/${app}/private/${host}.key",
            path => "/usr/bin",
            unless => "/bin/ls -l /etc/pki/${app}/certs/${host}.csr",
        }
    }

    # Define: createkey
    # Parameters:
    # $host
    #
    define createkey ($host) {
        exec { "create-${name}-${host}-key":
            command => "openssl genrsa -out /etc/pki/${name}/private/${host}.key 2048",
            path => "/usr/bin",
            unless => "/bin/ls -l /etc/pki/${name}/private/${host}.key",
        }
    }

    # Define: signcert
    # Parameters:
    # $host $ca
    #
    define signcert ($host, $ca) {
        exec { "sign-${ca}-${name}-${host}-cert":
            cwd => "/etc/pki/${ca}",
            command => "openssl ca -verbose -batch -config /etc/pki/${ca}/ssl.cnf -keyfile \
                        /etc/pki/${ca}/private/${ca}_ca_cert.key -cert \
                        /etc/pki/${ca}/${ca}_ca_cert.crt -out \
                        /etc/pki/${name}/certs/${host}.pem \
                        -outdir /etc/pki/${name}/certs \
                        -infiles /etc/pki/${name}/certs/${host}.csr",
            path => "/usr/bin",
            unless => "/bin/ls -l /etc/pki/${name}/certs/${host}.pem",
        }
    }

    # Define: createca
    # Parameters:
    # $country, $province, $city, $org
    #
    define createca ($country, $province, $city, $org) {
        exec { "create-${name}-ca":
            command => "openssl req -config /etc/pki/${name}/ssl.cnf -new -x509 -days 3650 \
                        -key /etc/pki/${name}/private/${name}_ca_cert.key -out \
                        /etc/pki/${name}/${name}_ca_cert.crt -extensions v3_ca \
                        -subj \"/C=${country}/ST=${province}/L=${city}/O=${org}/CN=${name}\"",
            path => "/usr/bin",
            unless => "/bin/ls /etc/pki/${name}/${name}_ca_cert.crt",
        }
    }

    # Define: createcakey
    # Parameters:
    # 
    #
    define createcakey () {
        exec { "create-${name}-cakey":
            command => "openssl genrsa -out /etc/pki/${name}/private/${name}_ca_cert.key 2048",
            path => "/usr/bin",
            unless => "/bin/ls /etc/pki/${name}/private/${name}_ca_cert.key",
        }
    }

    # Define: createserial
    # Parameters:
    # 
    #
    define createserial () {
        exec { "create-${name}-serial":
            command => "/bin/echo 01 > /etc/pki/${name}/serial",
            unless => "ls -l /etc/pki/${name}/serial",
            path => "/bin",
        }
    }

    # Define: createindex
    # Parameters:
    # 
    #
    define createindex () {
        exec { "create-${name}-index":
            command => "/bin/touch /etc/pki/${name}/index.txt",
            unless => "/bin/ls -l /etc/pki/${name}/index.txt",
        }
    }

    file { "/etc/pki":
        ensure => directory,
    }
    
    file { "/etc/pki/${openssl_ca_name}":
        ensure => directory,
        require => File["/etc/pki"],
    }
    
    file { "/etc/pki/${openssl_ca_name}/private":
        ensure => directory,
        require => File["/etc/pki/${openssl_ca_name}"],
    }

    createserial{"${openssl_ca_name}":
        require => File["/etc/pki/${openssl_ca_name}/private"],
    }

    createindex{"${openssl_ca_name}":
        require => Createserial["${openssl_ca_name}"],
    }

    createcakey{"${openssl_ca_name}":
        require => Createindex["${openssl_ca_name}"],
    }

    createca{"${openssl_ca_name}":
        country => "${openssl_country_code}",
        province => "Gauteng",
        city => "Johannesburg",
        org => "${openssl_org_name}",
        require => [Createcakey["${openssl_ca_name}"], File["${openssl_ca_name}"]],
    }

    file {"/etc/pki/baruwa":
        ensure => directory,
    }
    
    file {"/etc/pki/baruwa/certs":
        ensure => directory,
        require => File["/etc/pki/baruwa"],
    }
    
    file {"/etc/pki/baruwa/private":
        ensure => directory,
        require => File["/etc/pki/baruwa"],
    }

    createkey{"baruwa":
        host => "${openssl_common_name}",
        require => File["/etc/pki/baruwa/private"],
    }

    createcsr{"baruwa-common":
        app => "baruwa",
        ca => "${openssl_ca_name}",
        host => "${openssl_common_name}",
        ou => "${openssl_org_name}",
        cn => "${openssl_common_name}",
        country => "${openssl_country_code}",
        province => "Gauteng",
        city => "Johannesburg",
        require => [Createkey["baruwa"], Createca["${openssl_ca_name}"], File["/etc/pki/baruwa/certs"]],
    }

    signcert{"baruwa":
        host => "${openssl_common_name}",
        ca => "${openssl_ca_name}",
        require => [Createcsr["baruwa-common"], Createca["${openssl_ca_name}"]],
    }

    file { "${openssl_ca_name}":
        content => template("ssl/ssl.cnf.erb"),
        owner => "root",
        group => "root",
        require => File["/etc/pki/${openssl_ca_name}"],
        path => "/etc/pki/${openssl_ca_name}/ssl.cnf",
    }
}